Monty Python's Flying Circus: Just the Words - Episode 27: Whicker's World

# Episode Twenty-seven: Whicker's World

Court scene - multiple murderer
Icelandic saga
Court scene (Viking)
Stock Exchange report
Mrs Premise and Mrs Conclusion visit Jean Paul Satre
Whicker Island

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| The camera pans across Glencoe. The wind is whistling and climaxes with a great chord, which introduces...
| CAPTION: 'NJORL'S SAGA' 'ICELAND 1126'
| The caption fades. Continue the pan until we pick up Icelandic gentleman. He unravels a scroll and starts to read.
Icelandic Gent | I Eric ... um
| The camera pans away from him and picks up a man (Terry J) seated at the organ, his back to the camera. He is naked, and he looks identical to the way he did in that deceased classic of our time 'And now for something completely trivial'. He grins at the camera and plays a few chords. Quick cut to the announcer at his desk.
Announcer | And now ...
| Quick cut to close up of 'It's' man.
It's Man | It's ...
Voice | Monty Python's Flying Circus!
| Cut to a courtroom. Severe atmosphere.
Judge | Michael Norman Randall, you have been found guilty of the murder of Arthur Reginald Webster, Charles Patrick Trumpington, Marcel Agnes Bernstein, Lewis Anona Rudd, John Malcolm Kerr, Nigel Sinclair Robinson, Norman Arthur Potter, Felicity Jayne Stone, Jean-Paul Reynard, Rachel Shirley Donaldson, Stephen Jay Greenblatt, Karl-Heinz Mullet, Belinda Anne Ventham, Juan-Carlos Fernandez, Thor Olaf Stensgaard, Lord Kimberley of Pretoria, Lady Kimberley of Pretoria, The Right Honourable Nigel Warmsly Kimberley, Robert Henry Noonan and Felix James Bennett, on or about the morning of the 19th December 1972. Have you anything to say before I pass sentence?
Randall | Yes, sir. I'm very sorry.
Judge | Very sorry?
Randall | Yes, sir. It was a very very bad thing to have done and I'm really very ashamed of myself. I can only say it won't happen again. To have murdered so many people in such a short space of time is really awful, and I really am very, very, very sorry that I did it, and also that I've taken up so much of the court's valuable time listening to the sordid details of these senseless killings of mine. I would particularly like to say, a very personal and sincere 'sorry' to you, m'lud, for my appalling behaviour throughout this trial. I'd also like to say sorry to the police, for putting them to so much trouble (shot of three heavily bandaged exhausted-looking policemen behind him) for the literally hours of work they've had to put in, collecting evidence and identifying corpses and so forth. You know I think sometimes we ought to realize the difficult and often dangerous work involved in tracking down violent criminals like myself and I'd just like them to know that their fine work is at least appreciated by me.
| The policemen look embarrassed.
First Policeman | No, no, we were only doing our job.
Second Policeman | No, no, no, no.
Randall | It's very good of you to say that, but I know what you've been through.
First Policeman | No, no, we've had worse.
Third Policeman | It was plain sailing apart from the arrest.
Randall | I know and I'm grateful. I'd like to apologize too to the prosecuting counsel for dragging him in here morning after morning in such lovely weather.
Counsel | Well, I would have had to come in anyway.
Randall | Ah good, but what a presentation of a case!
Counsel | Oh thank you.
Randall | No, no, it's a privilege to watch you in action. I never had a chance.
Counsel | Oh yes you did.
Randall | Not after that summing up. Great.
Counsel | Oh thank you. (very chuffed)
Randall | And now I must come to the jury. What can I say. I've dragged you in here, day after day, keeping you away from your homes, your jobs, your loved ones, just to hear the private details of my petty atrocities.
Foreman | No, no, it was very interesting.
Randall | But you could have had a much nicer case.
Foreman | No, no, murder's much more fun.
First Juryman | Yes and so many of them.
Second Juryman | Excellent.
Third Juryman | We've had a terrific time. (the jury applauds)
Randall | (blows his nose, does a Dickie Attenborough) I'm sorry, I'm very moved. And so, m'lud, it only remains for you to pass the most savage sentence on me that the law can provide.
Judge | Well er... not necessarily.
Randall | No, m'lud, the full penalty of the law is hardly sufficient. I insist I must be made an example of.
Judge | Well yes and no. I mean society at large...
Randall | Oh no, m'lud. Not with mass murder.
Judge | But in this case, (to court) don't you think?
Court | Yes, yes!
Randall | Oh, come on, m'lud, you've got to give me life.
Court | No, no, no, no.
Randall | (to court at large) Well, ten years at least.
Judge | Ten years!
Court | Shame. Shame!
Randall | Well five then. Be fair.
Judge | No, no. I'm giving you three months.
Randall | Oh no, that's so embarrassing. I won't hear of it. Give me six...please.
Judge | Well, all right. Six months.
Randall | Thank you, m'lud.
Judge | But suspended.
Randall | Oh no.
Court | Hooray. (they applaud)
Foreman | Three cheers for the defendant. Hip. Hip.
Court | Hooray.
Foreman | Hip. Hip.
Court | Hooray.
Foreman | Hip. Hip.
Court | Hooray.
All | For he's a jolly good fellow, For he's a jolly good fellow, For he's a jolly good fellow...
Voice | (off ) Which nobody can deny.
| ANIMATION: manhunt inside a man. CAPTION: 'NJORL'S SAGA -- PART II'
| Pan across a bleak landscape.
Voice Over | This little-known Icelandic saga, written by an unknown hand in the late thirteenth century, has remained undiscovered until today. Now it comes to your screens for the first time. Fresh from the leaves of Iceland's history. The terrible 'Njorl's Saga'.
| Cut to Viking.
Viking | It's not that terrible.
| Cut to landscape. The announcer appears in the corner of the shot.
Announcer | No, I meant terribly violent.
| Cut to Viking.
Viking | Oh yeah, yeah.
| A Viking hut. A Viking comes out and has great difficulty mounting his horse.
Voice Over | Erik Njorl, son of Frothgar, leaves his home to seek Hangar the Elder at the home of Thorvald Nlodvisson, the son of Gudleif, half brother of Thorgier, the priest of Ljosa water, who took to wife Thurunn, the mother of Thorkel Braggart, the slayer of Cudround the powerful, who knew Howal, son of Geernon, son of Erik from Valdalesc, son of Arval Gristlebeard, son of Harken, who killed Bjortguaard in Sochnadale in Norway over Cudreed, daughter of Thorkel Long, the son of Kettle-Trout, the half son of Harviyoun Half-troll, father of Ingbare the Brave, who with Isenbert of Gottenberg the daughter of Hangbard the Fierce ... (fades and continues under:)
Another Voice Over | I must apologize for an error in the saga. Evidently Thorgier, the Priest of Ljosa water who took to wife Thurunn, the mother of Thorkel Braggart, the slayer of Gudmund the powerful, who knew Howal, son of Geernon, son of Erik from Vadalesc ... (fades under next speech)
| The Viking has still failed to mount his horse. Both he and the horse look a bit exasperated.
Original Voice Over | Well I'm afraid we're having a little trouble getting this very exciting Icelandic saga started. If any of you at home have any ideas about how to get this exciting saga started again here's the address to write to:
Third Voice Over | Help the Exciting Icelandic Saga, 18b MacNorten Buildings, Oban.
| CAPTION: 'HELP THE EXCITING ICELANDIC SAGA C/O MATCH OF THE DAY BBC TV THE LARCHES 26 WESTBROOK AVENUE FAVERSHAM KENT'
| Cut to an office: the announcer at a desk. At another desk a secretary, applies a deodorant spray to her bust.
Announcer | (to camera) Hello, well I was the third voice you heard just now. I'm sorry about that terrible mess.
| Cut to the Viking at wheel of car.
Viking | Well it wasn't all that terrible.
| Cut back to the office.
Announcer | No, no, I meant terrible in the sense of unfortunate.
| Cut to the Viking.
Viking | Oh.
| Cut back to the office.
Announcer | Anyway, our plea for assistance has been answered by the North Malden Icelandic Saga Society who've given us some very useful information about the saga and so we carry on now with 'Njorl's Saga' with our thanks going, once again, to the North Maiden Icelandic Saga Society.
| Cut to the Viking standing by his home. He is asleep.
Voice Over | Erik Njorl, son of Frothgar rode off into the desolate plain. (the Viking manages to mount the horse; he rides off) Day and night he rode, looking neither to right nor left. Stopping neither for food nor rest. (shots of Erik riding through a bleak landscape) Twelve days and nights he rode. Through rain and storm. Through wind and snow beyond the enchanted waterfall, (Erik rides past a Waterfall) through the elfin glades until he reached his goal. (shot of a modern road sign: 'North Malden - please drive carefully') He had found the rich and pleasant land beyond the mountains, (shots of Erik riding gently through a modern suburban shopping street) the land where golden streams sang their way through fresh green meadows. Where there were halls and palaces, an excellent swimming pool and one of the most attractive bonus incentive schemes for industrial development in the city. Only fifteen miles from excellent Thames-side docking facilities and within easy reach of the proposed M25. Here it was that Erik Njorl, son of Frothgar, met the mayor. Mr Arthur Huddinut, a local solicitor.
| Erik rides up to the town hall and is met by the mayor.
Mayor | Welcome to North Malden. (to camera) Yes, everyone is welcome to North Malden, none more so than the businessmen and investors who shape our society of the future. Here at North Malden...
| His voice fades under the following.
Voice Over | And we apologize to viewers of 'Njorl's Saga' who may be confused by some of the references to North Malden. After a frank exchange of views we have agreed to carry on showing this version supplied to us by the North Malden Icelandic Saga Society on the undertaking that future scenes will adhere more closely to the spirit of twelfth-century Iceland.
| Film leader countdown (5, 4, 3. . .) then shot of Erik riding away into bleak landscape.
Voice Over | With moist eyes, Erik leaves this happy land to return to the harsh uneconomic realities of life in the land of Ljosa waters. On his way Erik rested a while in the land of Bjornsstrand - the land of dark forces, where Gildor was King. (Erik comes to a river in a wood; he drinks) These were the dukes of the land of Bjornsstrand. (sudden shot of six armoured knights standing in a row) Proud warriors who bore on their chests the letters of their dread name.
| The knights move their shields to reveal on their breastplates the letters M.A.L.D.E.N. Shots of Erik battling with the knights. A telephone rings and the following conversation is heard.
Announcer's Voice | Hello? Is that the North Malden Icelandic Society?
Voice | Yes, that's right.
Announcer | About this saga.
Voice | Oh yes, the Icelandic saga.
Announcer | Yes.
Voice | Good, isn't it.
Announcer | Well er, I don't know, but you promised us that you would stick to the spirit of the original text.
Voice | Yes, that's right.
Announcer | Well I mean a lot of these things that are happening, well they just don't quite ring true.
| One of the knights is carrying a sign: 'Malden, Gateway to Industry'.
Voice | Well, it's a new interpretation really.
| Another carries a sign, 'ICI thanks Malden'.
Announcer | Well we don't want a new...
| FLASH FRAME CAPTION: 'INVEST IN MALDEN'
Announcer | ... I mean we wanted the proper thing... I mean just look what's happening now.
| More signs: 'Invest in Malden', 'Malden - 45% Interest Free Loans '.
Voice | Banners were a very important part of Icelandic lore, Mr Mills.
Announcer | No, no, I'm sorry I, I can't accept that, it's gone too far, I'm very sorry but we'll have to terminate the agreement. You're just trying to cash in on the BBC's exciting Icelandic saga.
| The knights are carrying more and more advertising banners and signs.
Voice | That's business, Mr Mills.
Announcer | Well, that's as maybe but it's not the way the BBC works.
Voice | Well I'm sorry you feel that way but er, you know, if you ever want to come to Malden...
| FLASH CAPTION: 'INVEST IN MALDEN'
| Film leader countdown (5, 4, 3...).
| CAPTION: 'NJORL'S SAGA -- PART III'
| Usual dramatic music. Fade music as we come up on a courtroom. A man, Mr Birchenhall, is giving evidence.
Man | 8 o'clock is a peak viewing hour so naturally we tend to stick to our comedy output - unless of course there's sport - because of course we know this is popular, and popularity is what television is about. Quite frankly I'm sick and tired of people accusing us of being ratings conscious.
Judge | (to the clerk of the court) Ratings conscious?
Clerk | Transmitting bland garbage, m'lud.
Judge | Thank you.
Man | Now I'm really cheesed off. I mean it's not your high-brow bleeding plays that pull in the viewers, you know.
Judge | (bored) Thank you.
Man | (getting more and more angry) I mean Joe Public doesn't want to sit down and watch three hours of documentaries every evening.
Judge | Thank you.
Man | He wants to sit down and he wants to be entertained, he doesn't want a load... (he is helped out of court by two policemen, still protesting violently) No really - I'm absolutely fed up with this. I really am.
Judge | (banging gavel) Case dismissed.
| The prosecuting counsel rises anxiously.
Prosecuting Counsel | Case dismissed, m'lud?
Judge | Oh all right, five years.
Prosecuting Counsel | Thank you, m'lud. (he sits)
Judge | Call the next case please.
Prosecuting Counsel | Call Erik Njorl, son of Frothgar, brother of Hangnor... (etc.).
Clerk | Call Erik Njorl ... (etc.),
Voices | (off) Call Erik Njorl .. , (etc.). (all calling at once)
| Erik comes into the dock. He is bandaged almost totally, like a cocoon, including his head. He wears a Viking fur hat, The usher approaches him with the card and Bible.
Usher | You are Erik Njorl, son of Frothgar...
Judge | Get on with it!
Usher | Will you raise your right hand.
Judge | He obviously can't raise his right hand, you silly usher person... can you raise your right leg Mr Njorl?
| Njorl shakes his head.
Usher | Can you raise any part of your body, Mr Njorl?
| Njorl leans over and whispers in the usher's ear.
Usher | I see... well, we'll skip that... well, just take the book in your right hand Mr Njorl without raising any part of your body... Oh ....
Judge | What is it now, you persistently silly usher?
Usher | He can't hold the Bible m'lud.
Judge | Well screw the Bible! Let's get on with this bleeding trial, I've got a Gay Lib meeting at 6 o'clock. Superintendent Lufthansa will you please read the charge.
Superintendent | Is a charge strictly necessary, m'lud?
Judge | (heavy aside) The press is here.
Superintendent | Oh sorry! Right, here we go. You are hereby charged. One, that you did, on or about 1126, conspire to publicize a London Borough in the course of a BBC saga; two, that you were wilfully and persistently a foreigner; three, that you conspired to do things not normally considered illegal; four, that you were caught in possession of an offensive weapon, viz, the big brown table down at the police station.
Judge | The big brown table down at the police station?
Superintendent | It's the best we could find, m'lud ... and five... all together now...
| The whole court shout together.
Court | Assaulting a police officer!
Prosecuting Counsel | Call Police Constable Pan-Am. (Pan-Am runs into court and starts beating Njorl with a truncheon) Into the witness box, constable ... there'll be plenty of time for that later on. (the policeman gets into box hitting at anyone within range; his colleagues restrain him) Now, you are Police Constable Pan-Am?
Constable | No, I shall deny that to the last breath in my body. (superintendent nods) Oh. Sorry, yes.
Prosecuting Counsel | Police constable, do you recognize the defendant?
Constable | No. Never seen him before in my life. (superintendent nods) Oh , yes, yes he's the one. He done it. I'd recognize him anywhere, sorry, super. (the superintendent looks embarrassed)
Prosecuting Counsel | Constable, will you please tell the court in your own words what happened?
Constable | Oh yes! (refers to his notebook) I was proceeding in a northerly direction up Alitalia Street when I saw the deceased (points at Njorl) standing at an upstairs window, baring her bosom at the general public. She then took off her ... wait a tick. Wrong story. (refers to his notebook) Ho yes! There were three nuns in a railway compartment and the ticket inspector says to one of them. (the superintendent shakes his head) No, anyway I clearly saw the deceased...
Clerk | Defendant.
Constable | Defendant! Sorry. Sorry, super. I clearly saw the defendant ... doing whatever he's accused of...Red-handed. When kicked... he said: 'It's a fair ... cop, I done it all ... Right... no doubt about... that'. Then, bound as he was to the chair, he assaulted myself and three other constables while bouncing around the cell. The end.
| Spontaneous applause from the court. Shouts of 'more! more!'. Pan-am raises his hands and the clapping and shouting dies down.
Constable | Thank you, thank you... and for my next piece of evidence...
Superintendent | I think you'd better leave it there, constable.
Prosecuting Counsel | Excellent evidence, constable (the constable is removed, flailing his truncheon the while) ... Thank you very much. Now then Mr Njorl, will you tell the court please where were you on the night of 1126? (silence from the bandages) Move any part of your body if you were north of a line from the Humbet to the Mersey. (silence)
Judge | Is he in there, d'you think? . .. Hello... Hello! Defendant, are you there ... coo-ee! De-fend-ant... (to the clerk of the court) I think you'd better go and have a look, Maurice.
Clerk | Don't call me Maurice in court!
Judge | I'm sorry.
| The clerk and prosecuting counsel and two policemen look inside Njorl, who is now in fact a framework of bandages with no one inside. From this oh-so zany situation only Terry 'Marty Feldman's Comedy Machine' Gilliam can save us ... Animated sketch, leading us into a studio set; a man is sitting in front of a non-animated (but cheap) graph labelled 'Stock Market Report'.
Voice Over | And now the Stock Market Report by Exchange Telegraph.
Man | Trading was crisp at the start of the day with some brisk business on the floor. Rubber hardened and string remained confident. Little bits of tin consolidated although biscuits sank after an early gain and stools remained anonymous. Armpits rallied well after a poor start. Nipples rose dramatically during the morning but had declined by mid-afternoon, while teeth clenched and buttocks remained firm. Small dark furry things increased severely on the floor, whilst rude jellies wobbled up and down, and bounced against rising thighs which had spread to all parts of the country by mid-afternoon. After lunch naughty things dipped sharply forcing giblets upwards with the nicky nacky noo. Ting tang tong rankled dithely, little tipples pooped and poppy things went pong! Gibble gabble gobble went the rickety rackety roo and ... (a bucketful of water descends on him)
| ANIMATION: ends with an animated woman going into a laundromat. Cut to the interior of a laundromat. Various shabby folk sitting around. Mrs Conclusion approaches Mrs Premise and sits down.
Mrs Conclusion | Hello, Mrs Premise.
Mrs Premise | Hello, Mrs Conclusion.
Mrs Conclusion | Busy day?
Mrs Premise | Busy! I've just spent four hours burying the cat.
Mrs Conclusion | Four hours to bury a cat?
Mrs Premise | Yes! It wouldn't keep still, wriggling about howling its head off.
Mrs Conclusion | Oh - it wasn't dead then?
Mrs Premise | Well, no, no, but it's not at all a well cat so as we were going away for a fortnight's holiday, I thought I'd better bury it just to be on the safe side.
Mrs Conclusion | Quite right. You don't want to come back from Sorento to a dead cat. It'd be so anticlimactic. Yes, kill it now, that's what I say.
Mrs Premise | Yes.
Mrs Conclusion | We're going to have our budgie put down.
Mrs Premise | Really? Is it very old?
Mrs Conclusion | No. We just don't like it. We're going to take it to the vet tomorrow.
Mrs Premise | Tell me, how do they put budgies down then?
Mrs Conclusion | Well it's funny you should ask that, but I've just been reading a great big book about how to put your budgie down, and apparently you can either hit them with the book, or, you can shoot them just there, just above the beak.
Mrs Premise | Just there!
Mrs Conclusion | Yes.
Mrs Premise | Well well well. 'Course, Mrs Essence flushed hers down the loo.
Mrs Conclusion | Ooh! No! You shouldn't do that - no that's dangerous. Yes, they breed in the sewers, and eventually you get evil-smelling flocks of huge soiled budgies flying out of people's lavatories infringing their personal freedom. (life-size cut-out of woman at end of last animation goes by) Good morning Mrs Cut-out.
Mrs Premise | It's a funny thing freedom. I mean how can any of us be really free when we still have personal possessions.
Mrs Conclusion | You can't. You can't. I mean, how can I go off and join Frelimo when I've got nine more installments to pay on the fridge.
Mrs Premise | No, you can't. You can't. Well this is the whole crux of Jean-Paul Sartre's 'Roads to Freedom'.
Mrs Conclusion | No, it bloody isn't. The nub of that is, his characters stand for all of us in their desire to avoid action. Mind you, the man at the off-licence says it's an everyday story of French country folk.
Mrs Premise | What does he know?
Mrs Conclusion | Nothing.
Mrs Premise | Sixty new pence for a bottle of Maltese Claret. Well I personally think Jean-Paul's masterwork is an allegory of man's search for commitment.
Mrs Conclusion | No it isn't.
Mrs Premise | Yes it is.
Mrs Conclusion | Isn't.
Mrs Premise | 'Tis.
Mrs Conclusion | No it isn't.
Mrs Premise | All right. We can soon settle this. We'll ask him.
Mrs Conclusion | Do you know him?
Mrs Premise | Yes, we met on holiday last year.
Mrs Conclusion | In Ibeezer?
Mrs Premise | Yes. He was staying there with his wife and Mr and Mr Genet. Oh, I did get on well with Madam S. We were like that.
Mrs Conclusion | What was Jean-Paul like?
Mrs Premise | Well, you know, a bit moody. Yes, he didn't join in the fun much. Just sat there thinking. Still, Mr Rotter caught him a few times with the whoopee cushion. (she demonstrates) Le Capitalisme et La Bourgeoisie ils sont la même chose... Oooh we did laugh.
Mrs Conclusion | Well, we'll give him a tinkle then.
Mrs Premise | Yes, all right. She said they were in the book. (shouts) Where's the Paris telephone directory?
Mrs Inference | It's on the drier.
Mrs Premise | No, no, that's Budapest. Oh here we are Sartre ... Sartre.
Mrs Varley | It's 621036.
Mrs Premise | Oh, thank you, Mrs Varley. (dials) Hallo. Paris 621036 please and make it snappy, buster... (as they wait they sing 'The Girl from Ipanema') Hallo? Hello Mrs Sartre. It's Beulagh Premise here. Oh, pardon, c'est Beulagh Premise ici, oui, oui, dans Ibeezer. Oui, we met... nous nous recontrons au Hotel Miramar. Oui, à la barbeque, c'est vrai. Madame S. - est-ce que Jean est chez vous? Oh merde. When will he be free? Oh pardon. Quand sera-t-il libre? Oooooh. Ha ha ha ha (to Mrs Conclusion) She says he's spent the last sixty years trying to work that one out. (to Madame Sartre) Très amusant, Madam S. Oui absolument... à bientôt. (puts the phone down) Well he's out distributing pamphlets to the masses but he'll be in at six.
Mrs Conclusion | Oh well, I'll ring BEA then.
| Cut to them sitting on a raft in mid-ocean.
Mrs Premise | Oh look, Paris!
| Cut to shot of a notice board on the seashore, it reads 'North Malden Welcomes Careful Coastal Craft'.
Mrs Conclusion | That's not Paris. Jean-Paul wouldn't live here. It's a right old dump.
| 'Alan Whicker', complete with microphone, walks in front of sign.
Whicker | But this is where they were wrong. For this was no old dump, but a town with a future, an urban El Dorado where the businessmen of today can enjoy the facilities of tomorrow in the comfort of yesterday. Provided by a go-getting, go-ahead council who know just how loud money can talk. (a phone off-screen starts to ring) Interest rates are so low...
| Cut to head of drama's office; he is on the phone.
Head of Drama | Well it's none of my business but we had the same trouble with one of our Icelandic sagas. These people are terribly keen but they do rather tend to take over. I think I'd stick to Caribbean Islands if I were you. (rings off) Fine... and now back to the saga.
| CAPTION: 'NJORL'S SAGA - PART IV'
| Thundering music. Cut to an Icelandic seashore. Dark and impressive. After a pause the pepperpots walk into shot.
Mrs Premise | Here - this is not Paris, this is Iceland.
Mrs Conclusion | Oh, well, Paris must be over there then. (points out to the sea; they walk back to the raft)
| Stock shot of Eiffel Tower. French accordion music. Mix through to French street thronged by old Frenchmen with berets and loaves. Mrs Conclusion and Mrs Premise appear and walk up to the front door of an apartment block. On the front door is a list of the inhabitants of the block. They read it out loud.
Mrs Premise | Oh, here we are, Number 25 .... (reads) Flat 1, Duke and Duchess of Windsor, Flat 2, Yves Montand, Flat 3, Jacques Cousteau, Flat 4, Jean Genet and Friend, Flat 5, Maurice Laroux...
Mrs Conclusion | Who's he?
Mrs Premise | Never heard of him. Flat 6, Marcel Marceau, 'Walking Against the Wind' Ltd. Flat 7, Indira Gandhi?
Mrs Conclusion | She gets about a bit, doesn't she?
Mrs Premise | Yes, Flat 8, Jean-Paul and Betty-Muriel Sartre.
| She rings the bell. A voice comes from the intercom.
Voice | Oui.
Mrs Premise | C'est nous, Betty-Muriel, excusez que nous sorerues en retard.
Voice | Entrez.
| Buzzer sounds.
Mrs Premise | Oui, merci.
| Interior the Sartres flat. It is littered with books and papers. We hear Jean-Paul coughing. Mrs Sartre goes to the door. She is a ratbag with a fag in her mouth and a duster over her head. A French song is heard on the radio. She switches it off.
Mrs Sartre | Oh, rubbish. (opens the door) Bonjour.
Mrs Conclusion | (entering) Parlez vous Anglais?
Mrs Sartre | Oh yes. Good day. (Mrs Premise comes in) Hello, love!
Mrs Premise | Hello! Oh this is Mrs Conclusion from No. 46.
Mrs Sartre | Nice to meet you, dear.
Mrs Conclusion | Hello.
Mrs Premise | How's the old man, then?
Mrs Sartre | Oh, don't ask. He's in one of his bleeding moods. 'The bourgeoisie this is the bourgeoisie that' - he's like a little child sometimes. I was only telling the Rainiers the other day - course he's always rude to them, only classy friends we've got - I was saying solidarity with the masses I said... pie in the sky! Oooh! You're not a Marxist are you Mrs Conclusion?
Mrs Conclusion | No, I'm a Revisionist.
Mrs Sartre | Oh good. I mean, look at this place! I'm at my wits end. Revolutionary leaflets everywhere. One of these days I'll revolutionary leaflets him. If it wasn't for the goat you couldn't get in here for propaganda.
| Shot of a goat eating leaflets in corner of room.
Mrs Premise | Oh very well. Can we pop in and have a word with him?
Mrs Sartre | Yes come along.
Mrs Premise | Thank you.
Mrs Sartre | But be careful. He's had a few. Mind you he's as good as gold in the morning, I've got to hand it to him, but come lunchtime it's a bottle of vin ordinaire - six glasses and he's ready to agitate.
| Mrs Premise and Mrs Conclusion knock on the door of Jean-Paul's room.
Mrs Premise | Coo-ee! Jean-Paul? Jean-Paul! It's only us. Oh pardon ... c'est même nous...
| They enter. We do not see Jean-Paul although we hear his voice.
Jean-Paul | Oui.
Mrs Premise | Jean-Paul. Your famous trilogy 'Rues à Liberté, is it an allegory of man's search for commitment?
Jean-Paul | Oui.
Mrs Premise | I told you so.
Mrs Conclusion | Oh coitus.
| Stock shot of a plane taking off
| CAPTION: 'THE END'
| A stock shot of a jet landing which they always use to introduce 'Whicker's World'. This leads us into Whicker Island - a tropical island paradise where all the inhabitants have Alan Whicker suits, glasses and microphones.
| CAPTION: 'WHICKER'S WORLD'
| Various Whickers pace past the camera.
First Whicker | Today we look at a vanishing race. A problem people who are fast disappearing off the face of the earth.
Second Whicker | A race who one might say are losing a winning battle.
Third Whicker | They live in a sunshine paradise, a Caribbean dream, where only reality is missing.
Fourth Whicker | For this is Whicker Island.
Fifth Whicker | An island inhabited entirely by ex-international interviewers in pursuit of the impossible dream.
First Whicker | The whole problem of Whicker Island is here in a nutshell.
Second Whicker | There are just too many Whickers.
Third Whicker | The light-weight suits.
Fourth Whicker | The old school tie.
Fifth Whicker | The practised voice of the seasoned campaigner.
First Whicker | Cannot hide the basic tragedy here.
Second Whicker | There just aren't enough rich people left to interview.
| Cut to a different location.
Third Whicker | You can't teach an old dog new tricks and so (turning to a swimming pool with lots of Whickers around it, wandering with stick mikes and muttering) you find them...
Fourth Whicker | (seated by swimming pool) Sitting beside elegant swimming pools...
Fifth Whicker | (seated at drinks table, with sun umbrella) ... sipping Martinis...
First Whicker | (standing by the pool) .. and waiting for the inevitable interview.
Second Whicker | (standing fully clothed in the pool) I talked to the island's only white man, Father Pierre.
| Cut to a different location. Feeling of heat. The third Whicker stands beside a priest in a white robe.
Third Whicker | Father Pierre, why did you stay on in this colonial Campari-land where the clink of glasses mingles with the murmur of a million mosquitoes, where waterfalls of whisky wash away the worries of a world-weary Whicker, where gin and tonic jingle in a gyroscopic jubilee of something beginning with J - Father Pierre, why did you stay on here?
Father Pierre | (putting on a pair of Whicker-style glasses) Well mainly for the interviews.
Fifth Whicker | Well there you have it, a crumbling...
First Whicker | ... empire in the sun-drenched...
Second Whicker | Caribbean, where the clichés sparkle on the waters...
Third Whicker | ... like the music of repeat fees...
First Whicker | And so...
Fifth Whicker | ... from Whicker Island...
First Whicker | ... it's...
Second Whicker | ... fare...
Third Whicker | ... well and...
Fourth Whicker | ... bon...
Fifth Whicker | . .. voy...
First Whicker | ... age.
| Cut to film of Whicker plane taking off. Roll credits, which read:
| WHICKER'S WORLD WAS CONCEIVED, WRITTEN AND PERFORMED BY ALAN WHICKER JOHN CLEESE WHICKER GRAHAM WHICKER CHAPMAN ALAN MICHAEL PALIN WHICKER ERIC WHICKER WH1CKER IDLE TERRY TERRY WHICKER ALAN GILLIAM ALSO APPEARING ALAN WHICKER MRS IDLE CONNIE WHICKER BOOTH RITA WHICKER DAVIES NIGEL WHICKER JONES FRANK WILLIAMS AS THE BOY WHICKER MAKE UP ALAN WHICKER AND MADELAINE GAFFNEY ALAN WHICKER COSTUMES HAZEL PETHIG ANIMATIONS BY TERRY WHICKER GILLIAM MR WHICKER KINDLY PHOTOGRAPHED ON FILM BY ALAN FEATHERSTONE EDITED ON FILM BY RAY MILLICHOPE MR WHICKER'S SOUND BY ALAN WHICKER, ALAN WHICKER AND RICHARD CHUBB MR WHICKER WAS ENTIRELY LIT BY JIMMY PURDIE (ASSISTED BY ALAN WHICKER) MR WHICKER WAS DESIGNED BY ROBERT BERK PRODUCED BY ALAN WHICKER OH, AND IAN MCNAUGHTON A BBC WHICKER COLOUR PRODUCTION